function varargout = FSDT_Simulator(varargin)

% This function is the control code of Simulator interface

% Written by Dmitry Tikhomirov
% Institut fuer Geologie, Universitaet Bern
% tikhomirov@geo.unibe.ch, tikhomirovdmitry@gmail.com
% 2013-2016
%
% This program is free software; you can redistribute it and/or modify it 
% under a Creative Commons Attribution-NonCommercial-ShareAlike 3.0 
% Unported License (http://creativecommons.org/licenses/by-nc-sa/3.0/)

%FSDT_SIMULATOR M-file for FSDT_Simulator.fig
%      FSDT_SIMULATOR, by itself, creates a new FSDT_SIMULATOR or raises the existing
%      singleton*.
%
%      H = FSDT_SIMULATOR returns the handle to a new FSDT_SIMULATOR or the handle to
%      the existing singleton*.
%
%      FSDT_SIMULATOR('Property','Value',...) creates a new FSDT_SIMULATOR using the
%      given property value pairs. Unrecognized properties are passed via
%      varargin to FSDT_Simulator_OpeningFcn.  This calling syntax produces a
%      warning when there is an existing singleton*.
%
%      FSDT_SIMULATOR('CALLBACK') and FSDT_SIMULATOR('CALLBACK',hObject,...) call the
%      local function named CALLBACK in FSDT_SIMULATOR.M with the given input
%      arguments.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help FSDT_Simulator

% Last Modified by GUIDE v2.5 03-Feb-2014 00:51:41

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @FSDT_Simulator_OpeningFcn, ...
                   'gui_OutputFcn',  @FSDT_Simulator_OutputFcn, ...
                   'gui_LayoutFcn',  [], ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
   gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT

% initialization of FSDT_Simulator
function initialize_FSDT_Simulator(fig_handle, handles, isreset)


% clean parpool if needed
delete(gcp('nocreate'))

handles.input_db_err = 0;
handles.approx_meth = 'linear';

handles.PR_Ca = [48.8 0 0];
handles.PR_K = [162 0 0];
handles.PR_Ti = [13 0 0];
handles.PR_Fe = [1.9 0 0];
handles.Pf = [757 0 0];
handles.input_mu = 0;
handles.input_UTh = 0;
handles.halflife = [301 0];

handles.sim_mode = 'rwmc';

handles.sc_scheme = 'St';

handles.dd_step = 0;
handles.hh_step = 0;
handles.d_parts = 3;
handles.h_parts = 5;

handles.tot_er_lim = [0 0];
handles.er_rate = [0 0 0];
handles.col_lev_corr = [0 0 0];
handles.exp_start = [0 0 0];
handles.ages = [zeros(2) [0;0]];
handles.col_pos = [zeros(2) [0;0]];

handles.chi_sigma = [0 3];
handles.param_num = [1 1];
handles.num_res = 1000;

handles.uitable_selection = [];
handles.db_in = 0;
handles.res_in = 0;

set(handles.text1, 'String', 'Please load existing database or create new one.');
set(handles.popupmenu13, 'Value', 1);
set(handles.edit50, 'String', handles.input_db_err);

set(handles.edit1, 'String', handles.PR_Ca(1));
set(handles.edit2, 'String', handles.PR_Ca(2));
set(handles.edit3, 'String', handles.PR_K(1));
set(handles.edit4, 'String', handles.PR_K(2));
set(handles.edit5, 'String', handles.PR_Ti(1));
set(handles.edit6, 'String', handles.PR_Ti(2));
set(handles.edit7, 'String', handles.PR_Fe(1));
set(handles.edit8, 'String', handles.PR_Fe(2));
set(handles.edit9, 'String', handles.Pf(1));
set(handles.edit10, 'String', handles.Pf(2));
set(handles.edit11, 'String', handles.input_mu);
set(handles.edit12, 'String', handles.input_UTh);
set(handles.edit26, 'String', handles.halflife(1));
set(handles.edit13, 'String', handles.halflife(2));

set(handles.edit14, 'String', handles.hh_step);
set(handles.edit15, 'String', handles.dd_step);
set(handles.edit16, 'String', handles.h_parts);
set(handles.edit17, 'String', handles.d_parts);

set(handles.popupmenu25, 'Value', 2);

set(handles.popupmenu7, 'Value', 5);

set(handles.edit18, 'String', handles.col_lev_corr(1));
set(handles.text38, 'String', 'mean ');
set(handles.edit19, 'String', handles.col_lev_corr(2));
set(handles.text39, 'String', 'stdev ');

set(handles.text51, 'Position', [28 16.75 30 1.25]);
set(handles.text47, 'Position', [28 12.75 30 1.25]);

set(handles.edit51, 'String', handles.tot_er_lim(1));
set(handles.edit52, 'String', handles.tot_er_lim(2));

set(handles.popupmenu10, 'Value', 1, 'Visible', 'Off');
set(handles.text48, 'String', 'mean ');
set(handles.edit20, 'String', handles.exp_start(1));
set(handles.text49, 'String', 'stdev ');
set(handles.edit21, 'String', handles.exp_start(2));
set(handles.popupmenu11, 'Value', 1, 'Visible', 'Off');
set(handles.text52, 'String', 'mean ');
set(handles.edit22, 'String', handles.er_rate(1));
set(handles.text53, 'String', 'stdev ');
set(handles.edit23, 'String', handles.er_rate(2));


tabledata = {'Norm' 'mean' 0 'stdev' 0 'Norm' 'mean' 0 'stdev' 0;...
             'Norm' 'mean' 0 'stdev' 0 'Norm' 'mean' 0 'stdev' 0};
set(handles.uitable1, 'Data',  tabledata);

set(handles.edit24, 'String', handles.num_res);
set(handles.popupmenu24, 'Value', 1);
set(handles.edit49, 'Visible', 'Off');
set(handles.popupmenu12, 'String', {'Chi-squared threshold'; 'Sigma confidence window '; 'Lowest chi-squared'});
set(handles.popupmenu12, 'Value', 3);
set(handles.edit25, 'Visible', 'Off');
set(handles.text107, 'Visible', 'Off');
guidata(handles.figure1, handles);


% --- Executes just before FSDT_Simulator is made visible.
function FSDT_Simulator_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   unrecognized PropertyName/PropertyValue pairs from the
%            command line (see VARARGIN)

% Choose default command line output for FSDT_Simulator
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

initialize_FSDT_Simulator(gcbf, handles, true);

% UIWAIT makes FSDT_Simulator wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = FSDT_Simulator_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


%--------------------Fault scarp database----------------------------------

% Create Database
function pushbutton1_Callback(hObject, eventdata, handles)

close all
FSDT_Database_Maker;




% Load Database
function pushbutton2_Callback(hObject, eventdata, handles)

last_db_mes = get(handles.text1, 'String');
set(handles.text1, 'String', 'Loading...');

[db_fileName, db_filePath] = uigetfile('*.mat');

% If "Cancel" is selected then return
if isequal([db_fileName, db_filePath],[0,0])
    set(handles.text1, 'String', last_db_mes);
    return
end
% Construct the fullfilename
db_file = fullfile(db_filePath, db_fileName);
load(db_file);
handles.DB = DB;
set(handles.text1, 'String', ['Database is loaded from the file: ' db_file]);

handles.hh_step = handles.DB.h_step;
handles.dd_step = handles.DB.d_step;
handles.tot_er_lim(2) = handles.DB.tot_er;
set(handles.edit14, 'String', handles.hh_step);
set(handles.edit15, 'String', handles.dd_step);
set(handles.edit51, 'String', handles.tot_er_lim(2));
handles.db_in = 1;

guidata(hObject,handles)


% Database error
function edit50_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val < 0)
    errordlg('Database error should be a positive number or zero!','Error');
    input_val = handles.input_db_err;
    set(hObject, 'String', input_val);
end

if input_val > 2
    msgbox('Too big database error can cause extremely long simulation!','Warning','warn');
end

handles.input_db_err = input_val;
guidata(hObject,handles)

function edit50_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% Approximation method
function popupmenu13_Callback(hObject, eventdata, handles)

choise = get(hObject,'Value');

switch choise
    case 1
        handles.approx_meth = 'linear';
    case 2
        handles.approx_meth = 'cubic';
    case 3
        handles.approx_meth = 'spline';
end

guidata(hObject,handles)

function popupmenu13_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


%-----------------Production rates & decay constant------------------------

% Spallation on Ca
function edit1_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val < 0)
    errordlg('Production rate should be a positive number!','Error');
    input_val = handles.PR_Ca(1);
    set(hObject, 'String', input_val);
end

handles.PR_Ca(1) = input_val;
guidata(hObject,handles)

function edit1_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function edit2_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val < 0)
    errordlg('Production rate error should be a positive number!','Error');
    input_val = handles.PR_Ca(2);
    set(hObject, 'String', input_val);
end

handles.PR_Ca(2) = input_val;
guidata(hObject,handles)

function edit2_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% Spallation on K
function edit3_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val < 0)
    errordlg('Production rate should be a positive number!','Error');
    input_val = handles.PR_K(1);
    set(hObject, 'String', input_val);
end

handles.PR_K(1) = input_val;
guidata(hObject,handles)

function edit3_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function edit4_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val < 0)
    errordlg('Production rate error should be a positive number!','Error');
    input_val = handles.PR_K(2);
    set(hObject, 'String', input_val);
end

handles.PR_K(2) = input_val;
guidata(hObject,handles)

function edit4_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

% Spallation on Ti
function edit5_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val < 0)
    errordlg('Production rate should be a positive number!','Error');
    input_val = handles.PR_Ti(1);
    set(hObject, 'String', input_val);
end

handles.PR_Ti(1) = input_val;
guidata(hObject,handles)

function edit5_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit6_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val < 0)
    errordlg('Production rate error should be a positive number!','Error');
    input_val = handles.PR_Ti(2);
    set(hObject, 'String', input_val);
end

handles.PR_Ti(2) = input_val;
guidata(hObject,handles)

function edit6_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

% Spallation on Fe
function edit7_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val < 0)
    errordlg('Production rate should be a positive number!','Error');
    input_val = handles.PR_Fe(1);
    set(hObject, 'String', input_val);
end

handles.PR_Fe(1) = input_val;
guidata(hObject,handles)

function edit7_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function edit8_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val < 0)
    errordlg('Production rate error should be a positive number!','Error');
    input_val = handles.PR_Fe(2);
    set(hObject, 'String', input_val);
end

handles.PR_Fe(2) = input_val;
guidata(hObject,handles)

function edit8_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% Production of thermal/epithermal neutrons
function edit9_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val < 0)
    errordlg('Production rate should be a positive number!','Error');
    input_val = handles.Pf(1);
    set(hObject, 'String', input_val);
end

handles.Pf(1) = input_val;
guidata(hObject,handles)

function edit9_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit10_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val < 0)
    errordlg('Production rate error should be a positive number!','Error');
    input_val = handles.Pf(2);
    set(hObject, 'String', input_val);
end

handles.Pf(2) = input_val;
guidata(hObject,handles)

function edit10_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

% Error of production by muons
function edit11_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val < 0)
    errordlg('Production rate error should be a positive number!','Error');
    input_val = handles.input_mu;
    set(hObject, 'String', input_val);
end

handles.input_mu = input_val;
guidata(hObject,handles)

function edit11_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

% Error of production by neutrons from U & Th
function edit12_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val < 0)
    errordlg('Production rate error should be a positive number!','Error');
    input_val = handles.input_UTh;
    set(hObject, 'String', input_val);
end

handles.input_UTh = input_val;
guidata(hObject,handles)

function edit12_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

% 36Cl half-life
function edit26_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val < 0)
    errordlg('Halflife should be a positive number!','Error');
    input_val = handles.halflife(1);
    set(hObject, 'String', input_val);
end

handles.halflife(1) = input_val;
guidata(hObject,handles)

function edit26_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function edit13_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val < 0)
    errordlg('Halflife error should be a positive number!','Error');
    input_val = handles.halflife(2);
    set(hObject, 'String', input_val);
end

handles.halflife(2) = input_val;
guidata(hObject,handles)

function edit13_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


%-----------------------Simulation mesh size-------------------------------

% Mesh size of the sample position on the scarp
function edit14_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val < 0)
    errordlg('Mesh size of the sample position on the scarp should be a positive number!','Error');
    input_val = handles.hh_step;
    set(hObject, 'String', input_val);
end

handles.hh_step = input_val;
guidata(hObject,handles)

function edit14_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

%Mesh size of the sample depth
function edit15_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val < 0)
    errordlg('Mesh size of the sample depth should be a positive number!','Error');
    input_val = handles.dd_step;
    set(hObject, 'String', input_val);
end

handles.dd_step = input_val;
guidata(hObject,handles)

function edit15_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

% Sample parts along position on the scarp
function edit16_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val < 0)
    errordlg('Number of sample parts along position on the scarp should be a natural number!','Error');
    input_val = handles.h_parts;
    set(hObject, 'String', input_val);
end

handles.h_parts = fix(input_val);
guidata(hObject,handles)

function edit16_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

% Sample parts along the depth
function edit17_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val < 0)
    errordlg('Number of sample parts along the depth should be a natural number!','Error');
    input_val = handles.d_parts;
    set(hObject, 'String', input_val);
end

handles.d_parts = fix(input_val);
guidata(hObject,handles)

function edit17_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


%---------------------------Simulation mode--------------------------------

function popupmenu25_Callback(hObject, eventdata, handles)

choise = get(hObject,'Value');

switch choise
    case 1
        handles.sim_mode = 'smc';

        handles.er_rate = [0 0 1];
        handles.col_lev_corr = [0 0 1];
        handles.exp_start = [0 0 1];
        handles.ages = [zeros(2) [1;1]];
        handles.col_pos = [zeros(2) [1;1]];

        set(handles.edit18, 'String', handles.col_lev_corr(1));
        set(handles.text38, 'String', 'min ');
        set(handles.edit19, 'String', handles.col_lev_corr(2));
        set(handles.text39, 'String', 'max ');

        set(handles.text51, 'Position', [3 16.75 30 1.25]);
        set(handles.text47, 'Position', [3 12.75 30 1.25]);

        set(handles.popupmenu10, 'Value', 2, 'Visible', 'On');
        set(handles.text48, 'String', 'min ');
        set(handles.edit20, 'String', handles.exp_start(1));
        set(handles.text49, 'String', 'max ');
        set(handles.edit21, 'String', handles.exp_start(2));

        set(handles.popupmenu11, 'Value', 2, 'Visible', 'On');
        set(handles.text52, 'String', 'min ');
        set(handles.edit22, 'String', handles.er_rate(1));
        set(handles.text53, 'String', 'max ');
        set(handles.edit23, 'String', handles.er_rate(2));

        tabledata = {'Unif' 'min' 0 'max' 0 'Unif' 'min' 0 'max' 0;...
                     'Unif' 'min' 0 'max' 0 'Unif' 'min' 0 'max' 0};
        set(handles.uitable1, 'Data',  tabledata);

        set(handles.popupmenu12, 'String', {'Chi-squared threshold'; 'Sigma confidence window '});

    case 2
        handles.sim_mode = 'rwmc';

        handles.er_rate = [0 0 0];
        handles.col_lev_corr = [0 0 0];
        handles.exp_start = [0 0 0];
        handles.ages = [zeros(2) [0;0]];
        handles.col_pos = [zeros(2) [0;0]];
        
        set(handles.edit18, 'String', handles.col_lev_corr(1));
        set(handles.text38, 'String', 'mean ');
        set(handles.edit19, 'String', handles.col_lev_corr(2));
        set(handles.text39, 'String', 'stdev ');
        
        set(handles.text51, 'Position', [28 16.75 30 1.25]);
        set(handles.text47, 'Position', [28 12.75 30 1.25]);
        
        set(handles.popupmenu10, 'Value', 1, 'Visible', 'Off');
        set(handles.text48, 'String', 'mean ');
        set(handles.edit20, 'String', handles.exp_start(1));
        set(handles.text49, 'String', 'stdev ');
        set(handles.edit21, 'String', handles.exp_start(2));
        
        set(handles.popupmenu11, 'Value', 1, 'Visible', 'Off');
        set(handles.text52, 'String', 'mean ');
        set(handles.edit22, 'String', handles.er_rate(1));
        set(handles.text53, 'String', 'stdev ');
        set(handles.edit23, 'String', handles.er_rate(2));
        
        tabledata = {'Norm' 'mean' 0 'stdev' 0 'Norm' 'mean' 0 'stdev' 0;...
                     'Norm' 'mean' 0 'stdev' 0 'Norm' 'mean' 0 'stdev' 0};
        set(handles.uitable1, 'Data',  tabledata);
        
        set(handles.popupmenu12, 'String', {'Chi-squared threshold'; 'Sigma confidence window '; 'Lowest chi-squared'});
end

handles.chi_sigma = [12 1];
handles.param_num = [1 1];
handles.num_res = 1000;

handles.uitable_selection = [];

set(handles.edit24, 'String', handles.num_res);
set(handles.popupmenu24, 'Value', 1);
set(handles.edit49, 'Visible', 'Off');
set(handles.popupmenu12, 'Value', 1);
set(handles.edit25, 'Visible', 'On');
set(handles.edit25, 'String', handles.chi_sigma(1));
set(handles.text107, 'Visible', 'Off');

guidata(hObject,handles)

function popupmenu25_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


%---------------------------Scaling scheme----------------------------------

function popupmenu7_Callback(hObject, eventdata, handles)

choise = get(hObject,'Value');

switch choise
    case 1
        handles.sc_scheme = 'De';
    case 2
        handles.sc_scheme = 'Li';
    case 3
        handles.sc_scheme = 'Du';
    case 4
        handles.sc_scheme = 'Lm';
    case 5
        handles.sc_scheme = 'St';
end

guidata(hObject,handles)

function popupmenu7_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


%------------------------Fault scarp history-------------------------------

% Table of ages and colluvium positions
function uitable1_CellEditCallback(hObject, eventdata, handles)

tabledata = get(handles.uitable1, 'Data');

eqnum = size(tabledata,1);
ages = zeros(eqnum,3);
col_pos = zeros(eqnum,3);

for i = 1:eqnum
    if strcmp(tabledata(i,1),'Unif') && strcmp(handles.sim_mode,'smc')
        tabledata(i,2) = {'min'};
        tabledata(i,4) = {'max'};
        ages(i,:) = [cell2mat([tabledata(i,3) tabledata(i,5)]) 1];
    elseif strcmp(tabledata(i,1),'Unif') && strcmp(handles.sim_mode,'rwmc')
        tabledata(i,1) = {'Norm'};
        set(handles.uitable1, 'Data',  tabledata);
        errordlg('Only normal distribution is available in Random Walk mode.','Error');
    elseif strcmp(tabledata(i,1),'Norm')
        tabledata(i,2) = {'mean'};
        tabledata(i,4) = {'stdev'};
        ages(i,:) = [cell2mat([tabledata(i,3) tabledata(i,5)]) 0];
    end
    
    if strcmp(tabledata(i,6),'Unif') && strcmp(handles.sim_mode,'smc')
        tabledata(i,7) = {'min'};
        tabledata(i,9) = {'max'};
        col_pos(i,:) = [cell2mat([tabledata(i,8) tabledata(i,10)]) 1];
    elseif strcmp(tabledata(i,6),'Unif') && strcmp(handles.sim_mode,'rwmc')
        tabledata(i,6) = {'Norm'};
        set(handles.uitable1, 'Data',  tabledata);
        errordlg('Only normal distribution is available in Random Walk mode.','Error');
    elseif strcmp(tabledata(i,6),'Norm')
        tabledata(i,7) = {'mean'};
        tabledata(i,9) = {'stdev'};
        col_pos(i,:) = [cell2mat([tabledata(i,8) tabledata(i,10)]) 0];
    end
        
end
table_in = [ages col_pos];
if any(any(isnan(table_in))) || any(any(table_in< 0))
    errordlg('Input should be a positive number or zero!','Error');
    tabledata = [tabledata(:,1:2) num2cell(handles.ages(:,1)) tabledata(:,4) num2cell(handles.ages(:,2))...
                 tabledata(:,6:7) num2cell(handles.col_pos(:,1)) tabledata(:,9) num2cell(handles.col_pos(:,2))];
else
handles.ages = ages;
handles.col_pos = col_pos;    
end

set(hObject, 'Data', tabledata);
selection = eventdata.Indices(:,1);
selection = unique(selection);
handles.uitable_selection = selection;
guidata(hObject,handles)

function uitable1_CellSelectionCallback(hObject, eventdata, handles)

selection = eventdata.Indices(:,1);
selection = unique(selection);
handles.uitable_selection = selection;
guidata(hObject,handles)


% Add event button
function pushbutton3_Callback(hObject, eventdata, handles)

if strcmp(handles.sim_mode,'smc')
    line_in = {'Unif' 'min' 0 'max' 0 'Unif' 'min' 0 'max' 0};
elseif strcmp(handles.sim_mode,'rwmc')
    line_in = {'Norm' 'mean' 0 'stdev' 0 'Norm' 'mean' 0 'stdev' 0};
end

tabledata = get(handles.uitable1, 'Data');
table_legth = size(tabledata,1);
if isempty(handles.uitable_selection)
    tabledata = [tabledata; line_in];
    handles.ages = [handles.ages; 0 0 1];
    handles.col_pos = [handles.col_pos; 0 0 1];
elseif handles.uitable_selection >=1 && handles.uitable_selection <= table_legth
    tabledata = [tabledata(1:(handles.uitable_selection-1),:); line_in;...
                  tabledata(handles.uitable_selection:table_legth,:)];
    handles.ages = [handles.ages(1:(handles.uitable_selection-1),:); 0 0 1;...
                    handles.ages(handles.uitable_selection:table_legth,:)];
    handles.col_pos = [handles.col_pos(1:(handles.uitable_selection-1),:); 0 0 1;...
                       handles.col_pos(handles.uitable_selection:table_legth,:)];
end
set(handles.uitable1,'Data',tabledata)
handles.selection = [];
guidata(hObject,handles)


% Delete event button
function pushbutton4_Callback(hObject, eventdata, handles)

tabledata = get(handles.uitable1, 'data');
table_legth = size(tabledata,1);
if isempty(handles.uitable_selection) == 1 && table_legth > 0
    tabledata(table_legth,:) = [];
    handles.ages(table_legth,:) = [];
    handles.col_pos(table_legth,:) = [];
elseif isempty(handles.uitable_selection) == 0 && handles.uitable_selection >=1
    tabledata(handles.uitable_selection,:) = [];
    handles.ages(handles.uitable_selection,:) = [];
    handles.col_pos(handles.uitable_selection,:) = [];
end
set(handles.uitable1,'data',tabledata);
handles.selection = [];
guidata(hObject,handles)


% Total erosion
function edit51_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val < 0)
    errordlg('Total erosion should be a positive number or zero!','Error');
    input_val = handles.tot_er_lim(1);
    set(hObject, 'String', input_val);
end

handles.tot_er_lim(1) = input_val;
guidata(hObject,handles)

function edit51_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit52_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val < 0)
    errordlg('Total erosion should be a positive number or zero!','Error');
    input_val = handles.tot_er_lim(2);
    set(hObject, 'String', input_val);
end

handles.tot_er_lim(2) = input_val;
guidata(hObject,handles)

function edit52_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% Reference point correction
function edit18_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val)
    errordlg('Reference point correction should be a number!','Error');
    input_val = handles.col_lev_corr(1);
    set(hObject, 'String', input_val);
end

handles.col_lev_corr(1) = input_val;
guidata(hObject,handles)

function edit18_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit19_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val)
    errordlg('Reference point correction should be a number!','Error');
    input_val = handles.col_lev_corr(2);
    set(hObject, 'String', input_val);
end

handles.col_lev_corr(2) = input_val;
guidata(hObject,handles)

function edit19_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% Begining of exposure
function popupmenu10_Callback(hObject, eventdata, handles)

choice = get(hObject,'Value');

switch choice
    case 1
        handles.exp_start = [0 0 0];
        set(handles.text48, 'String', 'mean ');
        set(handles.edit20, 'String', handles.exp_start(1));
        set(handles.text49, 'String', 'stdev ');
        set(handles.edit21, 'String', handles.exp_start(2));
    case 2
        handles.exp_start = [0 0 1];
        set(handles.text48, 'String', 'min ');
        set(handles.edit20, 'String', handles.exp_start(1));
        set(handles.text49, 'String', 'max ');
        set(handles.edit21, 'String', handles.exp_start(2)); 
end    

guidata(hObject,handles)

function popupmenu10_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit20_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val < 0)
    errordlg('Age should be a positive number or zero!','Error');
    input_val = handles.exp_start(1);
    set(hObject, 'String', input_val);
end

handles.exp_start(1) = input_val;
guidata(hObject,handles)

function edit20_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit21_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val < 0)
    errordlg('Age should be a positive number or zero!','Error');
    input_val = handles.exp_start(2);
    set(hObject, 'String', input_val);
end

handles.exp_start(2) = input_val;
guidata(hObject,handles)

function edit21_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% Erosion rate
function popupmenu11_Callback(hObject, eventdata, handles)

choice = get(hObject,'Value');

switch choice
    case 1
        handles.er_rate = [0 0 0];
        set(handles.text52, 'String', 'mean ');
        set(handles.edit22, 'String', handles.er_rate(1));
        set(handles.text53, 'String', 'stdev ');
        set(handles.edit23, 'String', handles.er_rate(2));
    case 2
        handles.er_rate = [0 0 1];
        set(handles.text52, 'String', 'min ');
        set(handles.edit22, 'String', handles.er_rate(1));
        set(handles.text53, 'String', 'max ');
        set(handles.edit23, 'String', handles.er_rate(2)); 
end    

guidata(hObject,handles)

function popupmenu11_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit22_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || input_val < 0
    errordlg('Erosion rate should be a positive number!','Error');
    input_val = handles.er_rate(1);
    set(hObject, 'String', input_val);
end

handles.er_rate(1) = input_val;
guidata(hObject,handles)

function edit22_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function edit23_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val)
    errordlg('Erosion rate should be a positive number!','Error');
    input_val = handles.er_rate(2);
    set(hObject, 'String', input_val);
end

handles.er_rate(2) = input_val;
guidata(hObject,handles)

function edit23_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% -------------------Simulation parameters---------------------------------

% Number of successful simulations
function edit24_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val <= 0)
    errordlg('Number of successful simulations should be a natural number!','Error');
    input_val = handles.num_res;
    set(hObject, 'String', input_val);
end

handles.num_res = fix(input_val);
set(hObject, 'String', handles.num_res);
guidata(hObject,handles)

function edit24_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% Number of calculated parameters
function popupmenu24_Callback(hObject, eventdata, handles)

handles.param_num(2) = get(hObject,'Value');

switch handles.param_num(2)
    case 1
        set(handles.edit49, 'Visible', 'Off');
    case 2
        set(handles.edit49, 'Visible', 'On', 'String', handles.param_num(1));
end

if handles.chi_sigma(2) == 2
    eq_num= size(handles.ages,1);
    handles.data_num = length(handles.DB.sam_36Clconc);
    switch handles.param_num(2)
        case 1
            param_num_temp = eq_num*2 + 2;
        case 2
            param_num_temp = handles.param_num(1);
    end

    deg_free = handles.data_num - param_num_temp;
    chi_max = chi2inv((2*normcdf(handles.chi_sigma(1),0,1) - 1),deg_free)/deg_free;
    set(handles.text107, 'Visible', 'On', 'String', ['Chi-sq.= ' num2str(chi_max)]);
end

guidata(hObject,handles)

function popupmenu24_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit49_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val <= 0)
    errordlg('Number of calculated parameters should be a natural number!','Error');
    input_val = handles.param_num(1);
    set(hObject, 'String', input_val);
end

if handles.chi_sigma(2) == 2
    handles.data_num = length(handles.DB.sam_36Clconc);
    deg_free = handles.data_num - input_val;
    chi_max = chi2inv((2*normcdf(handles.chi_sigma(1),0,1) - 1),deg_free)/deg_free;
    set(handles.text107, 'Visible', 'On', 'String', ['Chi-sq.= ' num2str(chi_max)]);
end

handles.param_num(1) = fix(input_val);
set(hObject, 'String', handles.param_num(1));
guidata(hObject,handles)

function edit49_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

% Chi-squared threshold or sigma confidence window
function edit25_Callback(hObject, eventdata, handles)

input_val = str2double(get(hObject, 'String'));

if isnan(input_val) || (input_val <= 0)
    errordlg('Confidence window size or chi-squared threshold should be a positive number!','Error');
    input_val = handles.chi_sigma(1);
    set(hObject, 'String', input_val);
end

handles.chi_sigma(1) = input_val;

if handles.chi_sigma(2) == 2
    eq_num= size(handles.ages,1);
    switch handles.param_num(2)
        case 1
            param_num_temp = eq_num*2 + 2;
        case 2
            param_num_temp = handles.param_num(1);
    end
    handles.data_num = length(handles.DB.sam_36Clconc);
    deg_free = handles.data_num - param_num_temp;
    chi_max = chi2inv((2*normcdf(handles.chi_sigma(1),0,1) - 1),deg_free)/deg_free;
    set(handles.text107, 'Visible', 'On', 'String', ['Chi-sq.= ' num2str(chi_max)]);
end
guidata(hObject,handles)

function edit25_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function popupmenu12_Callback(hObject, eventdata, handles)

input_val = get(hObject,'Value');

if handles.db_in == 0;
    input_val = handles.chi_sigma(2);
    set(hObject, 'Value', input_val);
    errordlg('Please load database.','Error');
    return
else
    handles.chi_sigma(2) = input_val;
end

if handles.chi_sigma(2) == 1
    handles.chi_sigma(1) = 12;
    set(handles.edit25, 'String', handles.chi_sigma(1), 'Visible', 'On');
    set(handles.text107, 'Visible', 'Off')
elseif handles.chi_sigma(2) == 2
    handles.chi_sigma(1) = 2;
    set(handles.edit25, 'String', handles.chi_sigma(1), 'Visible', 'On');
    eq_num= size(handles.ages,1);
    switch handles.param_num(2)
        case 1
            param_num_temp = eq_num*2 + 2;
        case 2
            param_num_temp = handles.param_num(1);
    end
    handles.data_num = length(handles.DB.sam_36Clconc);
    deg_free = handles.data_num - param_num_temp;
    chi_max = chi2inv((2*normcdf(handles.chi_sigma(1),0,1) - 1),deg_free)/deg_free;
    set(handles.text107, 'Visible', 'On', 'String', ['Chi-sq.= ' num2str(chi_max)]);
elseif handles.chi_sigma(2) == 3
    handles.chi_sigma(1) = 0;
    set(handles.edit25, 'Visible', 'Off');
    set(handles.text107, 'Visible', 'Off')
end

guidata(hObject,handles)

function popupmenu12_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


%-----------------------Control buttons------------------------------------

% Reset button
function pushbutton5_Callback(hObject, eventdata, handles)

close all
FSDT_Simulator;

% Help button
function pushbutton6_Callback(hObject, eventdata, handles)

close(findobj('Type','figure','Name','FSDT_Simulator_Help'));

fid = fopen( fullfile('Simulator_Help.txt') );
str_S_help = textscan(fid, '%s', 'Delimiter','\n');
str_S_help = str_S_help{1};
fclose(fid);

hFig_S_help = figure('Menubar','none', 'Toolbar','none', 'Name','FSDT_Simulator_Help',...
    'NumberTitle', 'off','Color',[0.941, 0.941, 0.941]);

hEdit_S_help = uicontrol(hFig_S_help, 'Style','edit', 'FontSize',9, ...
    'Min',0, 'Max',2, 'HorizontalAlignment','left', ...
    'Units','normalized', 'Position',[0 0 1 1], ...
    'BackgroundColor','white','String',str_S_help);


% About button
function pushbutton7_Callback(hObject, eventdata, handles)

close(findobj('Type','figure','Name','FSDT_About'));

fid = fopen( fullfile('About.txt') );
str_About = textscan(fid, '%s', 'Delimiter','\n');
str_About = str_About{1};
fclose(fid);

hFig_About  = figure('Menubar','none', 'Toolbar','none', 'Name','FSDT_About',...
    'NumberTitle', 'off','Color',[0.941, 0.941, 0.941],'Units','characters','Position', [50 20 80 18]);

hText_About  = uicontrol(hFig_About , 'Style','text', 'FontSize',9, ...
    'Min',0, 'Max',2, 'HorizontalAlignment','center', ...
    'Units','normalized', 'Position',[0 0 1 1],'String',str_About );

% Probability Density Plot button
function pushbutton8_Callback(hObject, eventdata, handles)

if handles.db_in == 0;
    errordlg('Please load database.','Error');
    return
end

sam_mid = (handles.DB.sam_top + handles.DB.sam_bot)/2;
sam_spCa_av = mean(handles.DB.sam_spCa);
sam_36Clconc_norm = handles.DB.sam_36Clconc./handles.DB.sam_spCa.*sam_spCa_av;
sam_36Clerr_norm = handles.DB.sam_36Clerr./handles.DB.sam_spCa.*sam_spCa_av;

Probability_Density_Plot(sam_mid,sam_36Clconc_norm,sam_36Clerr_norm);



% Run button
function pushbutton9_Callback(hObject, eventdata, handles)

% Check some of input data
if handles.db_in == 0;
    errordlg('Please load database.','Error');
    return
end

if max(max(handles.ages(:,(1:2)))) > handles.DB.t_lim
    errordlg('Oldest earthquake age should be less than or equal to maximal exposure age of the database.','Error');
    return
end
if max(handles.exp_start(1:2)) > handles.DB.t_lim
    errordlg('Beginning of exposure should be less than or equal to maximal exposure age of the database.','Error');
    return
end
if max(abs(handles.col_lev_corr(1:2))) > handles.DB.max_coll_lev_corr
    errordlg('Absolute value of reference point correction should be less than or equal to maximal reference point error of the database.','Error');
    return
end
if handles.col_lev_corr(3) == 0
    stripe_top = max(handles.DB.sam_top) - handles.col_lev_corr(1);
elseif handles.col_lev_corr(3) == 1
    stripe_top = max(handles.DB.sam_top) - min(handles.col_lev_corr(1),handles.col_lev_corr(2));
end
t_pos = round_from_zero(stripe_top,handles.hh_step);

if max(max(handles.col_pos(:,(1:2)))) > handles.DB.tot_slip
    errordlg('The greatest colluvium position along fault scarp height should be less than or equal to maximal total slip of the database.','Error');
    return
end
if max(max(handles.col_pos(:,(1:2)))) < t_pos
    errordlg(['The greatest colluvium position along fault scarp height should be greater than or equal to stripe top'...
             '(considering reference point correction and mesh spacing along fault scarp height.)'],'Error');
    return
end

% Ask before the run
choice3 = questdlg(['You are ready to run Monte-Carlo simulation. This process can take from several minutes upto couple of days.'...
                    ' Be ready to keep your computer on for this period. Progress bar gives you estimation of remaining time.'...
                    ' Stop button ends the simulation process, and collected successful simulations are shown as a result.' ' Start the simulation process?'], ...
	                'Start the simulation process?', ...
	                'Start','No','No');
switch choice3
    case 'No'
        return
    case 'Start'
end

% Format some inputs
sam_num = length(handles.DB.sam_top);
handles.Var_db = ones(sam_num,1)*[1 handles.input_db_err/100 0];
decay = log(2)/(handles.halflife(1)*1000);
handles.decay = [decay decay*handles.halflife(2)/handles.halflife(1) 0];
handles.Var_mu = [1 handles.input_mu/100 0];
handles.Var_UTh = [1 handles.input_UTh/100 0];

% Run the simulation
if strcmp(handles.sim_mode,'smc')
    RT = MonteCarloScarp(handles.DB,handles.Var_db,handles.chi_sigma,handles.num_res,handles.param_num,...
                         handles.ages,handles.col_pos,handles.exp_start,handles.col_lev_corr,handles.er_rate,handles.tot_er_lim,handles.sc_scheme,...
                         handles.PR_Ca,handles.PR_K,handles.PR_Ti,handles.PR_Fe,handles.Pf,handles.Var_mu,handles.Var_UTh,handles.decay,...
                         handles.dd_step,handles.hh_step,handles.approx_meth,handles.d_parts,handles.h_parts);
elseif strcmp(handles.sim_mode,'rwmc')
    RT = RandomWalkScarp(handles.DB,handles.Var_db,handles.chi_sigma,handles.num_res,handles.param_num,...
                         handles.ages,handles.col_pos,handles.exp_start,handles.col_lev_corr,handles.er_rate,handles.tot_er_lim,handles.sc_scheme,...
                         handles.PR_Ca,handles.PR_K,handles.PR_Ti,handles.PR_Fe,handles.Pf,handles.Var_mu,handles.Var_UTh,handles.decay,...
                         handles.dd_step,handles.hh_step,handles.approx_meth,handles.d_parts,handles.h_parts);
end

% If there are no results
if RT.oppa == 0
    errordlg(['No sucsessful simulations after ' num2str(RT.tot_tries) ' tries!'],'Error');
    return
elseif RT.oppa == 1
    errordlg(['No sucsessful simulations after ' num2str(RT.tot_tries) ' tries! The product of the erosion rate and the exposure age of the sample stripe'...
              ' is greater than the maximum total erosion of the database. Try to reduce the erosion rate and/or the exposure age of the sample stripe.'],'Error');
    return
end


% Otherwise draw result
handles.main_res = Main_Result(handles.chi_sigma,RT.min_chi,RT.AICc,RT.RMSw,RT.suc_tries,RT.tot_tries,...
                               RT.chi_ages,RT.chi_col_pos,RT.chi_exp_start,RT.chi_clc,RT.chi_er_rate,...
                               RT.N_chi,handles.DB.sam_36Clconc,handles.DB.sam_36Clerr,handles.DB.sam_top,handles.DB.sam_bot);
    
handles.hist_over = Histogram_Overview(RT.ages,RT.col_pos);
eqnum = size(handles.ages,1);
handles.param_zero = Parameter_Window(RT.exp_start,RT.chi_exp_start,RT.mean_exp_start,RT.max_exp_start,RT.min_exp_start,RT.median_exp_start,RT.mode_exp_start,...
                                      RT.er_rate,RT.chi_er_rate,RT.mean_er_rate,RT.max_er_rate,RT.min_er_rate,RT.median_er_rate,RT.mode_er_rate,...
                                      RT.chi,RT.min_chi,0);
for i = 1:(eqnum)
    handles.param(i) = Parameter_Window(RT.ages(i,:),RT.chi_ages(i),RT.mean_ages(i),RT.max_ages(i),RT.min_ages(i),RT.median_ages(i),RT.mode_ages(i),...
                                       RT.col_pos(i,:),RT.chi_col_pos(i),RT.mean_col_pos(i),RT.max_col_pos(i),RT.min_col_pos(i),RT.median_col_pos(i),RT.mode_col_pos(i),...
                                       RT.chi,RT.min_chi,i);
end

handles.RT = RT;
handles.res_in = 1;
guidata(hObject,handles)


% Save button
function pushbutton10_Callback(hObject, eventdata, handles)

if handles.res_in == 0;
    errordlg('You have no result to save.','Error');
    return
end
% Ask for a file name to save the result
[FileName,PathName]=uiputfile({'*.tif','TIFF image (*.tif)';...
                               '*.bmp','Bitmap file (*.bmp)';...
                               '*.ai','Adobe Illustrator file (*.ai)';...
                               '*.eps','EPS file (*.eps)';...
                               '*.emf','Enhanced metafile (*.emf)';...
                               '*.jpg','JPEG image (*.jpg)';...
                               '*.png','Portable Network Graphics File (*.png)';...
                               '*.fig','MATLAB Figure (*.fig)'},...
                               'Save Result As');

% If "Cancel" is selected then return
if isequal([FileName,PathName],[0,0])
   	return
end
% Construct full file name and cut it
FFile = fullfile(PathName,FileName);
[useless1, l_name, pic_ext] = fileparts(FFile);


% Create and save log file
LogFileName = [l_name '_input_data.txt'];
LogFile = fullfile(PathName,LogFileName);
FFile_print = strrep(FFile,'\','/');
fid = fopen(LogFile,'wt');

fprintf(fid,'RESULTS OF SIMULATION\n');
fprintf(fid,['Name of the file with simulatiuon results: ' l_name '.xls\n']);
fprintf(fid,['Path of the file with simulatiuon results: ' FFile_print '\n']);
fprintf(fid,['Created ' datestr(now) '\n\n']);

fprintf(fid,'DATABASE\n');
db_mes = get(handles.text1, 'String');
db_mes = strrep(db_mes,'\','/');
fprintf(fid,[db_mes '\n']);
fprintf(fid,['Database error: '  num2str(handles.input_db_err) ' %%\n']);
fprintf(fid,['Approximation method: '  handles.approx_meth '\n\n']);

fprintf(fid,'PRODUCTION RATES\n');
fprintf(fid,['Neutron spallation on Ca: ' num2str(handles.PR_Ca(1)) ' +- ' num2str(handles.PR_Ca(2)) ' at/g yr\n']);
fprintf(fid,['Neutron spallation on K: ' num2str(handles.PR_K(1)) ' +- ' num2str(handles.PR_K(2)) ' at/g yr\n']);
fprintf(fid,['Neutron spallation on Ti: ' num2str(handles.PR_Ti(1)) ' +- ' num2str(handles.PR_Ti(2)) ' at/g yr\n']);
fprintf(fid,['Neutron spallation on Fe: ' num2str(handles.PR_Fe(1)) ' +- ' num2str(handles.PR_Fe(2)) ' at/g yr\n']);
fprintf(fid,['Epithermal neutrons from fast netrons: ' num2str(handles.Pf(1)) ' +- ' num2str(handles.Pf(2)) ' n/g yr\n']);
fprintf(fid,['Error in muonic production rates: '  num2str(handles.input_mu) ' %%\n']);
fprintf(fid,['Error in production by neutrons from U and Th: '  num2str(handles.input_UTh) ' %%\n\n']);

fprintf(fid,'36Cl HALF-LIFE\n');
fprintf(fid,['36Cl half-life: ' num2str(handles.halflife(1)) ' +- ' num2str(handles.halflife(2)) ' kyr\n\n']);

fprintf(fid,'SIMULATION MESH SIZE\n');
fprintf(fid,['Sample position mesh: '  num2str(handles.hh_step) ' cm\n']);
fprintf(fid,['Depth mesh: '  num2str(handles.dd_step) ' cm\n']);
fprintf(fid,['Sample parts along position on the scarp: '  num2str(handles.h_parts) '\n']);
fprintf(fid,['Sample parts along depth: '  num2str(handles.d_parts) '\n\n']);

fprintf(fid,'SCALING SCHEME\n');
switch handles.sc_scheme
    case 'De'
        scaling = 'Desilets et al. (2006)';
    case 'Li'
        scaling = 'Lifton (2005)';
    case 'Du'
        scaling = 'Dunai (2001)';
    case 'Lm'
        scaling = 'Lal (1991) - Stone (2000)';
    case 'St'
        scaling = 'Stone (2000)';
end
fprintf(fid,['Scaling scheme folowing: ' scaling '\n\n']);

fprintf(fid,'FAULT SCARP HISTORY\n\n');
fprintf(fid,'Earthquake ages, yr\n');
eqnum = length(handles.RT.chi_col_pos);
for i = 1:eqnum
    if handles.ages(i,3) == 0
        fprintf(fid,[num2str(i) ') mean = ' num2str(handles.ages(i,1)) '   stdev = ' num2str(handles.ages(i,2)) '\n']);
    elseif handles.ages(i,3) == 1
        fprintf(fid,[num2str(i) ') min = ' num2str(handles.ages(i,1)) '   max = ' num2str(handles.ages(i,2)) '\n']);
    end
end
fprintf(fid,'\n');

fprintf(fid,'Colluvium positions, cm\n');
for i = 1:eqnum
    if handles.col_pos(i,3) == 0
        fprintf(fid,[num2str(i) ') mean = ' num2str(handles.col_pos(i,1)) '   stdev = ' num2str(handles.col_pos(i,2)) '\n']);
    elseif handles.col_pos(i,3) == 1
        fprintf(fid,[num2str(i) ') min = ' num2str(handles.col_pos(i,1)) '   max = ' num2str(handles.col_pos(i,2)) '\n']);
    end
end
fprintf(fid,'\n');

fprintf(fid,'Beginning of exposure, yr\n');
if handles.exp_start(3) == 0
    fprintf(fid,['mean = ' num2str(handles.exp_start(1)) '   stdev = ' num2str(handles.exp_start(2)) '\n\n']);
elseif handles.exp_start(3) == 1
    fprintf(fid,['min = ' num2str(handles.exp_start(1)) '   max = ' num2str(handles.exp_start(2)) '\n\n']);
end

fprintf(fid,'Erosion rate, cm/kyr\n');
if handles.er_rate(3) == 0
    fprintf(fid,['mean = ' num2str(handles.er_rate(1)) '   stdev = ' num2str(handles.er_rate(2)) '\n\n']);
elseif handles.er_rate(3) == 1
    fprintf(fid,['min = ' num2str(handles.er_rate(1)) '   max = ' num2str(handles.er_rate(2)) '\n\n']);
end

fprintf(fid,'Total erosion, cm\n');
fprintf(fid,['min = ' num2str(handles.tot_er_lim(1)) '   max = ' num2str(handles.tot_er_lim(2)) '\n\n']);

fprintf(fid,'Reference point correction, cm\n');
if handles.col_lev_corr(3) == 0
    fprintf(fid,['mean = ' num2str(handles.col_lev_corr(1)) '   stdev = ' num2str(handles.col_lev_corr(2)) '\n\n']);
elseif handles.col_lev_corr(3) == 1
    fprintf(fid,['min = ' num2str(handles.col_lev_corr(1)) '   max = ' num2str(handles.col_lev_corr(2)) '\n\n']);
end
    
fprintf(fid,'SIMULATION PARAMETERS\n\n');

if strcmp(handles.sim_mode,'smc')
    fprintf(fid,'Simulation mode: Simple Monte-Carlo.\n');
else
    fprintf(fid,'Simulation mode: Random Walk Monte-Carlo.\n');
end

fprintf(fid,['Number of successful simulations: '  num2str(handles.num_res) '\n']);
switch handles.param_num(2)
    case 1
        fprintf(fid,['Default number of calculated paremeters: ' num2str(eqnum*2+2) '\n']);
    case 2
        fprintf(fid,['Number of calculated parameters is entered manualy: ' num2str(handles.param_num(1)) '\n']);
end
switch handles.chi_sigma(2)
    case 1
        fprintf(fid,['Chi-squared threshold: ' num2str(handles.chi_sigma(1)) '\n']);
    case 2
        fprintf(fid,['Sigma confidence window: ' num2str(handles.chi_sigma(1)) '\n']);
    case 3
        fprintf(fid,'Search for lowest chi-squared is chosen.\n');
end

fclose(fid);


% Save resulting figures and redraw if some of them are missing
if isempty(findobj('Type','figure','Name','Main_Result'))
    handles.main_res = Main_Result(handles.chi_sigma,handles.RT.min_chi,handles.RT.AICc,handles.RT.RMSw,handles.RT.suc_tries,handles.RT.tot_tries,...
                               handles.RT.chi_ages,handles.RT.chi_col_pos,handles.RT.chi_exp_start,handles.RT.chi_clc,handles.RT.chi_er_rate,...
                               handles.RT.N_chi,handles.DB.sam_36Clconc,handles.DB.sam_36Clerr,handles.DB.sam_top,handles.DB.sam_bot);
end

if isempty(findobj('Type','figure','Name','Histogram_Overview'))
    handles.hist_over = Histogram_Overview(handles.RT.ages,handles.RT.col_pos);
end

if isempty(findobj('Type','figure','Name','Beginning_of_Exposure_and_Erosion_Rate'))
    handles.param_zero = Parameter_Window(handles.RT.exp_start,handles.RT.chi_exp_start,handles.RT.mean_exp_start,handles.RT.max_exp_start,handles.RT.min_exp_start,handles.RT.median_exp_start,handles.RT.mode_exp_start,...
                                          handles.RT.er_rate,handles.RT.chi_er_rate,handles.RT.mean_er_rate,handles.RT.max_er_rate,handles.RT.min_er_rate,handles.RT.median_er_rate,handles.RT.mode_er_rate,...
                                          handles.RT.chi,handles.RT.min_chi,0);
end


FileName = [l_name '_conc_curve' pic_ext];
FFile = fullfile(PathName,FileName);
saveas(handles.main_res,FFile);

FileName = [l_name '_hist_overview' pic_ext];
FFile = fullfile(PathName,FileName);
saveas(handles.hist_over,FFile);

FileName = [l_name '_begin_of_exp_er_rate' pic_ext];
FFile = fullfile(PathName,FileName);
saveas(handles.param_zero,FFile);

for i = 1:eqnum
    
    if isempty(findobj('Type','figure','Name',['Earthquake_' num2str(i)]))
        handles.param(i) = Parameter_Window(handles.RT.ages(i,:),handles.RT.chi_ages(i),handles.RT.mean_ages(i),handles.RT.max_ages(i),handles.RT.min_ages(i),handles.RT.median_ages(i),handles.RT.mode_ages(i),...
                                            handles.RT.col_pos(i,:),handles.RT.chi_col_pos(i),handles.RT.mean_col_pos(i),handles.RT.max_col_pos(i),handles.RT.min_col_pos(i),handles.RT.median_col_pos(i),handles.RT.mode_col_pos(i),...
                                            handles.RT.chi,handles.RT.min_chi,i);
    end
    
    FileName = [l_name '_earthquake_' num2str(i) pic_ext];
    FFile = fullfile(PathName,FileName);
    saveas(handles.param(i),FFile);
end


% Save xls file with result
FFile = fullfile(PathName,[l_name '_result.xls']);

% Clean the file, if it already exist
if exist(FFile,'file') ~= 0
    cleanXlsSheets(FFile);
end
% Construct result
result11 = {'BEST FIT RESULT' '' '';...
           '' '' '';...
           'Age, yr' 'Slip, cm' 'Position of colluvium before earthquake, cm'};

chi_slips = handles.RT.chi_col_pos - [handles.RT.chi_col_pos(2:eqnum);0];
result12 = [handles.RT.chi_ages chi_slips handles.RT.chi_col_pos];
result12 = num2cell(result12);
result13 = {'' '' '';...
            'Begining of exposure, yr' '' '';...
            '' '' handles.RT.chi_exp_start;...
            'Reference point correction, cm' '' '';...
            '' '' handles.RT.chi_clc;...
            'Errosion rate, cm/kyr' '' '';...
            '' '' handles.RT.chi_er_rate;};
result1 = [result11;result12;result13];

res2_line = 12 + eqnum;
result21 = {'SIMULATION STATISTICS' '' '' '' '' '' '';
            '' '' '' '' '' '' '';
            'RMSw:' '' '' handles.RT.RMSw '' '' '';
            'Lowest chi-squared:' '' '' handles.RT.min_chi '' '' '';
            'Akaike information criterion:' '' '' handles.RT.AICc '' '' '';
            'Number of successful simulations:' '' '' handles.RT.suc_tries '' '' '';
            'Total number of simulations:' '' '' handles.RT.tot_tries '' '' '';
            '' '' '' '' '' '' '';'' '' '' '' '' '' ''};
result22= {'' 'Lowest Chi' 'Mode' 'Mean' 'Median' 'Min' 'Max'};
result23 = cell(eqnum*2,1);
for i = 1:eqnum
    result23(i) = {['Age ' num2str(i) ', yr']};
    result23(eqnum + i) = {['Position ' num2str(i) ', cm']};
end
result24 = [handles.RT.chi_ages handles.RT.mode_ages handles.RT.mean_ages handles.RT.median_ages handles.RT.min_ages handles.RT.max_ages;...
            handles.RT.chi_col_pos handles.RT.mode_col_pos handles.RT.mean_col_pos handles.RT.median_col_pos handles.RT.min_col_pos handles.RT.max_col_pos];
result24 = num2cell(result24);
result25 = {'Begining of exposure, yr' handles.RT.chi_exp_start handles.RT.mode_exp_start handles.RT.mean_exp_start handles.RT.median_exp_start handles.RT.min_exp_start handles.RT.max_exp_start;...
            'Reference point correction, cm' handles.RT.chi_clc handles.RT.mode_clc handles.RT.mean_clc handles.RT.median_clc handles.RT.min_clc handles.RT.max_clc;...
            'Erosion rate, cm/kyr' handles.RT.chi_er_rate handles.RT.mode_er_rate handles.RT.mean_er_rate handles.RT.median_er_rate handles.RT.min_er_rate handles.RT.max_er_rate};           

result2 = [result21;result22;result23 result24;result25];

res3_line = 26 + 3*eqnum;
sam_mid = (handles.DB.sam_top + handles.DB.sam_bot)./2 + handles.RT.chi_clc;
samnum = length(handles.DB.sam_36Clconc);
dummy = cell(1,samnum - 1);
result3 = [{'CONCENTRATION CURVES'} dummy; {''} dummy;...
            {'Corrected positions of sample centers, cm'} dummy;
            num2cell(sam_mid);
            {'Best fit concentrations, 1e5 at/g'} dummy;
            num2cell(handles.RT.N_chi);
            {'Measured concentrations, 1e5 at/g'} dummy;
            num2cell(handles.DB.sam_36Clconc);
            {'Error in measured concentrations, 1e5 at/g'} dummy;
            num2cell(handles.DB.sam_36Clerr)];

result41 = [result23' {'Begining of exposure, yr' 'Reference point correction, cm' 'Erosion rate, cm/kyr' 'Chi-squared value'}];
result42 = [handles.RT.ages' handles.RT.col_pos' handles.RT.exp_start' handles.RT.col_lev_cor' handles.RT.er_rate' handles.RT.chi'];
result42 = num2cell(result42);
raw_result = [result41;result42];

% Save raw result in .mat file
RT = handles.RT;
FFile_mat = fullfile(PathName,[l_name '_raw_result.mat']);
save(FFile_mat,'RT');

% Save result as xls file
xlswrite(FFile,result1,'Results','A1')
xlswrite(FFile,result2,'Results',['A' num2str(res2_line)])
xlswrite(FFile,result3,'Results',['A' num2str(res3_line)])
xlswrite(FFile,raw_result,'All simulations','A1')
