function out  = Histogram_Overview(ages,col_pos)

% creates a window containing a histogram of all resulting ages and 
% a histogram of all resulting colluvium positions

% Written by Dmitry Tikhomirov
% Institut fuer Geologie, Universitaet Bern
% tikhomirov@geo.unibe.ch, tikhomirovdmitry@gmail.com
% 2013-2016
%
% This program is free software; you can redistribute it and/or modify it 
% under a Creative Commons Attribution-NonCommercial-ShareAlike 3.0 
% Unported License (http://creativecommons.org/licenses/by-nc-sa/3.0/)

out = figure('Units','characters',...
             'Position', [50, 10, 203, 42],...
             'Name', 'Histogram_Overview',...  
             'NumberTitle', 'off','Color',[0.941, 0.941, 0.941],... 
             'MenuBar', 'none','PaperPositionMode', 'auto');

axes1 = axes('Units', 'characters','Position', [15 4 185 15]);
axes2 = axes('Units', 'characters','Position', [15 24 185 15]);

button1 = uicontrol('Style', 'pushbutton',...
                    'Units', 'characters','Position', [3 1 10 2],...
                    'FontSize',9,'String', 'Print',...
                    'Callback', {@print_fig_callback});

all_ages = [];
all_col_pos = [];
eqnum = size(ages,1);
for i = 1:eqnum
    all_ages = [all_ages ages(i,:)];
    all_col_pos = [all_col_pos col_pos(i,:)];
end
min_all_ages = min(all_ages);
max_all_ages = max(all_ages);
if min_all_ages == max_all_ages
    if min_all_ages == 0
        cent_ages = -0.05:0.05:0.05;
    else
        cent_ages = (0.95:0.05:1.05)*min_all_ages;
    end
else
    step_ages = ((max_all_ages - min_all_ages)/(eqnum*50));
    cent_ages = min_all_ages:step_ages:max_all_ages;
end
min_all_col_pos = min(all_col_pos);
max_all_col_pos = max(all_col_pos);
if min_all_col_pos == max_all_col_pos
    if min_all_col_pos == 0
        cent_col_pos = -0.05:0.05:0.05;
    else
        cent_col_pos = (0.95:0.05:1.05)*min_all_col_pos;
    end
else
    step_col_pos = ((max_all_col_pos - min_all_col_pos)/(eqnum*50));
    cent_col_pos = min_all_col_pos:step_col_pos:max_all_col_pos;
end

f_ages = hist(all_ages,cent_ages);
f_col_pos = hist(all_col_pos,cent_col_pos);

delta_ages = (max(cent_ages) - min(cent_ages))*0.1;
xl_ages = [(min(cent_ages) - delta_ages) (max(cent_ages) + delta_ages)];
delta_col_pos = (max(cent_col_pos) - min(cent_col_pos))*0.1;
xl_col_pos = [(min(cent_col_pos) - delta_col_pos) (max(cent_col_pos) + delta_col_pos)];

bar(axes2, cent_ages, f_ages, 'r', 'EdgeColor', 'r')
hold(axes2, 'on')
plot(axes2,cent_ages,smooth(f_ages,7),'b','linewidth',2)
xlabel(axes2, 'Age, yr')
ylabel(axes2, 'Frequency')
xlim(axes2,xl_ages)
ylim(axes2,[0 max(f_ages)*1.1])

bar(axes1, cent_col_pos, f_col_pos, 'r', 'EdgeColor', 'r')
hold(axes1, 'on')
plot(axes1,cent_col_pos,smooth(f_col_pos,7),'b','linewidth',2)
xlabel(axes1, 'Colluvium position before earthquake, cm')
ylabel(axes1, 'Frequency')
xlim(axes1,xl_col_pos)
ylim(axes1,[0 max(f_col_pos)*1.1])

function print_fig_callback(hObject, eventdata)

set(hObject, 'Visible', 'off');
[file,path]=uiputfile({'*.tif','TIFF image (*.tif)';...
                       '*.bmp','Bitmap file (*.bmp)';...
                       '*.ai','Adobe Illustrator file (*.ai)';...
                       '*.eps','EPS file (*.eps)';...
                       '*.emf','Enhanced metafile (*.emf)';...
                       '*.jpg','JPEG image (*.jpg)';...
                       '*.png','Portable Network Graphics File (*.png)';...
                       '*.fig','MATLAB Figure (*.fig)'},...
                       'Save Image As');
                   
% If "Cancel" is selected then return
if isequal([file,path],[0,0])
    set(hObject, 'Visible', 'on');
   	return
end

saveas(gcf,fullfile(path, file));
set(hObject, 'Visible', 'on');
         