 function out = Main_Result(chi_cut,min_chi,AICc,RMSw,suc_tries,tot_tries,...
                           chi_ages,chi_col_pos,chi_exp_start,chi_clc,chi_er_rate,N_th,...
                           sam_36Clconc,sam_36Clerr,sam_top,sam_bot)

% creates a window containing main result: best-fit 36Cl profile, measured
% 36Cl profile, best-fit ages, slips, colluvium positions, statistical
% characteristics of best-fit solution etc.

% Written by Dmitry Tikhomirov
% Institut fuer Geologie, Universitaet Bern
% tikhomirov@geo.unibe.ch, tikhomirovdmitry@gmail.com
% 2013-2016
%
% This program is free software; you can redistribute it and/or modify it 
% under a Creative Commons Attribution-NonCommercial-ShareAlike 3.0 
% Unported License (http://creativecommons.org/licenses/by-nc-sa/3.0/)
                       
                       
out = figure('Units','characters',...
             'Position', [50, 10, 203, 42],...
             'Name', 'Main_Result',...  
             'NumberTitle', 'off','Color',[0.941, 0.941, 0.941],... 
             'MenuBar', 'none','PaperPositionMode', 'auto');

eqnum = length(chi_col_pos);
sam_mid = (sam_top + sam_bot)./2 - chi_clc;
chi_slips = chi_col_pos - [chi_col_pos(2:eqnum);0];
min_conc = min([(sam_36Clconc - sam_36Clerr) N_th]);
max_conc = max([(sam_36Clconc + sam_36Clerr) N_th]);
delta_conc_sc = (max_conc - min_conc)*0.12;
xl = [(min_conc - delta_conc_sc) (max_conc + delta_conc_sc)];
delta_pos = (max(sam_mid) - min(sam_mid))*0.12;
yl = [(min(sam_mid) - delta_pos) (max(sam_mid)+delta_pos)];

axes1 = axes('Units', 'characters','Position', [15 4 138 35]);

plot(axes1,sam_36Clconc,sam_mid,'LineStyle','none','Marker','.','MarkerSize',8,'Color','k')
hold on
xlim(axes1,xl)
ylim(axes1,yl)
xlabel(axes1, '^{36}Cl concentration, 10^{5} at g^{-1}')
ylabel(axes1, 'Position along fault scarp, cm')

chi_conc = interp1(sam_mid,N_th,chi_col_pos);
for i = 2:eqnum
    line([chi_conc(i) (chi_conc(i) + delta_conc_sc)], [chi_col_pos(i) chi_col_pos(i)], 'Color','r','LineStyle','-');
    line([chi_conc(i) chi_conc(i)], [chi_col_pos(i) (chi_col_pos(i) + delta_pos)], 'Color','r','LineStyle','-');
    eq_name = char([num2str(round(chi_ages(i))) ' yr '], [num2str(round(chi_slips(i))) ' cm ']);
    text(chi_conc(i),(chi_col_pos(i) + delta_pos),eq_name,'HorizontalAlignment','right','VerticalAlignment','top', 'Color','r');
end
eq_name = char([num2str(round(chi_ages(1))) ' yr '], [num2str(round(chi_slips(1))) ' cm ']);
text(max(N_th),(max(sam_mid)+delta_pos*0.9),eq_name,'HorizontalAlignment','left','VerticalAlignment','top', 'Color','r');

for i = 1:length(sam_36Clconc)
    plot(axes1,[(sam_36Clconc(i) - sam_36Clerr(i)) (sam_36Clconc(i) + sam_36Clerr(i))], [sam_mid(i) sam_mid(i)],'Color','k')
end
plot(axes1,N_th,sam_mid,'LineStyle','none','Marker','o','MarkerSize',8,'Color','b')
plot(axes1,xl, [-chi_clc -chi_clc],'Color','b')
table_data = round([chi_ages chi_slips chi_col_pos]);
table1 = uitable('Units', 'characters',...
                 'Position', [155.5 21 44.5 18],...
                 'Data',  table_data,... 
                 'ColumnName', {'Age, yr' 'Slip, cm' 'Position, cm'},...
                 'ColumnFormat', {'numeric', 'numeric', 'numeric'},... 
                 'FontSize',9,...
                 'ColumnEditable', [false false false]);
             
uicontrol('Style','text','FontSize',9,'String','Begining of exposure:',...
          'Units', 'characters','Position',[157.5 18 30 1.5],'HorizontalAlignment','left');
uicontrol('Style','text','FontSize',9,'String','Reference point correction:',...
          'Units', 'characters','Position',[157.5 16 30 1.5],'HorizontalAlignment','left');
uicontrol('Style','text','FontSize',9,'String','Erosion rate:',...
          'Units', 'characters','Position',[157.5 14 30 1.5],'HorizontalAlignment','left');
uicontrol('Style','text','FontSize',9,'String','RMSw:',...
          'Units', 'characters','Position',[157.5 12 15 1.5],'HorizontalAlignment','left');
uicontrol('Style','text','FontSize',9,'String','Chi-squared:',...
          'Units', 'characters','Position',[157.5 10 15 1.5],'HorizontalAlignment','left');
uicontrol('Style','text','FontSize',9,'String','AICc:',...
          'Units', 'characters','Position',[157.5 8 15 1.5],'HorizontalAlignment','left');
uicontrol('Style','text','FontSize',9,'String','Successful simulations:',...
          'Units', 'characters','Position',[157.5 6 30 1.5],'HorizontalAlignment','left');
uicontrol('Style','text','FontSize',9,'String','Total simulations:',...
          'Units', 'characters','Position',[157.5 4 30 1.5],'HorizontalAlignment','left');
switch chi_cut(2)
    case 1
        uicontrol('Style','text','FontSize',9,'String','Chi-squared threshold:',...
                  'Units', 'characters','Position',[157.5 2 30 1.5],'HorizontalAlignment','left');
        uicontrol('Style','text','FontSize',9,'String',num2str(chi_cut(1)),...
                  'Units', 'characters','Position',[188 2 14 1.5],'HorizontalAlignment','left');
    case 2
        uicontrol('Style','text','FontSize',9,'String','Sigma confidence window:',...
                  'Units', 'characters','Position',[157.5 2 30 1.5],'HorizontalAlignment','left');
        uicontrol('Style','text','FontSize',9,'String',num2str(chi_cut(1)),...
                  'Units', 'characters','Position',[188 2 14 1.5],'HorizontalAlignment','left');
    case 3
        uicontrol('Style','text','FontSize',9,'String','Search for the lowest chi-squared',...
                  'Units', 'characters','Position',[157.5 2 44 1.5],'HorizontalAlignment','left');
end

uicontrol('Style','text','FontSize',9,'String',[num2str(chi_exp_start,'%.0f') ' yr'],...
          'Units', 'characters','Position',[188 18 14 1.5],'HorizontalAlignment','left');
uicontrol('Style','text','FontSize',9,'String',[num2str(chi_clc,'%.1f') ' cm'],...
          'Units', 'characters','Position',[188 16 14 1.5],'HorizontalAlignment','left');
uicontrol('Style','text','FontSize',9,'String',[num2str(chi_er_rate,'%.3f') ' cm/kyr'],...
          'Units', 'characters','Position',[174 14 14 1.5],'HorizontalAlignment','left');
uicontrol('Style','text','FontSize',9,'String',num2str(RMSw),...
          'Units', 'characters','Position',[174 12 14 1.5],'HorizontalAlignment','left');
uicontrol('Style','text','FontSize',9,'String',num2str(min_chi),...
          'Units', 'characters','Position',[174 10 14 1.5],'HorizontalAlignment','left');
uicontrol('Style','text','FontSize',9,'String',num2str(AICc),...
          'Units', 'characters','Position',[174 8 14 1.5],'HorizontalAlignment','left');
uicontrol('Style','text','FontSize',9,'String',num2str(suc_tries),...
          'Units', 'characters','Position',[188 6 14 1.5],'HorizontalAlignment','left');
uicontrol('Style','text','FontSize',9,'String',num2str(tot_tries),...
          'Units', 'characters','Position',[188 4 14 1.5],'HorizontalAlignment','left');
      
button1 = uicontrol('Style', 'pushbutton',...
                    'Units', 'characters','Position', [3 1 10 2],...
                    'FontSize',9,'String', 'Print',...
                    'Callback', {@print_fig_callback});

function print_fig_callback(hObject, eventdata)

set(hObject, 'Visible', 'off');
[file,path]=uiputfile({'*.tif','TIFF image (*.tif)';...
                       '*.bmp','Bitmap file (*.bmp)';...
                       '*.ai','Adobe Illustrator file (*.ai)';...
                       '*.eps','EPS file (*.eps)';...
                       '*.emf','Enhanced metafile (*.emf)';...
                       '*.jpg','JPEG image (*.jpg)';...
                       '*.png','Portable Network Graphics File (*.png)';...
                       '*.fig','MATLAB Figure (*.fig)'},...
                       'Save Image As');
                   
% If "Cancel" is selected then return
if isequal([file,path],[0,0])
    set(hObject, 'Visible', 'on');
   	return
end

saveas(gcf,fullfile(path, file));
set(hObject, 'Visible', 'on');
         