function out = Probability_Density_Plot(hh,conc,err)

% creates a window containing probability density plot

% Written by Dmitry Tikhomirov
% Institut fuer Geologie, Universitaet Bern
% tikhomirov@geo.unibe.ch, tikhomirovdmitry@gmail.com
% 2013-2016
%
% This program is free software; you can redistribute it and/or modify it 
% under a Creative Commons Attribution-NonCommercial-ShareAlike 3.0 
% Unported License (http://creativecommons.org/licenses/by-nc-sa/3.0/)

out = figure('Units','characters',...
             'Position', [50, 10, 190, 45],...
             'Name', 'Probability_Density_Plot',...  
             'NumberTitle', 'off','Color',[0.941, 0.941, 0.941],... 
             'MenuBar', 'none','PaperPositionMode', 'auto');
         
axes1 = axes('Units', 'characters','Position', [14 4 160 40]);

slider1 = uicontrol('Style', 'slider', 'Value', 0.5,...
                    'Units', 'characters','Position', [182 4 5 40],...
                    'Callback', {@slider_callback,hh,conc,err});

button1 = uicontrol('Style', 'pushbutton',...
                    'Units', 'characters','Position', [3 1 10 2],...
                    'FontSize',9,'String', 'Print',...
                    'Callback', {@print_fig_callback,slider1});
      
stdev_corr = 1;

plot_pd(hh,conc,err,stdev_corr)

function slider_callback(hObject, eventdata,hh,conc,err)

stdev_corr = 2^(get(hObject,'Value')*4 - 2);

plot_pd(hh,conc,err,stdev_corr)
      
function print_fig_callback(hObject, eventdata,slider1)

set(hObject, 'Visible', 'off');
set(slider1, 'Visible', 'off');
[file,path]=uiputfile({'*.tif','TIFF image (*.tif)';...
                       '*.bmp','Bitmap file (*.bmp)';...
                       '*.ai','Adobe Illustrator file (*.ai)';...
                       '*.eps','EPS file (*.eps)';...
                       '*.emf','Enhanced metafile (*.emf)';...
                       '*.jpg','JPEG image (*.jpg)';...
                       '*.png','Portable Network Graphics File (*.png)';...
                       '*.fig','MATLAB Figure (*.fig)'},...
                       'Save Image As');
                   
% If "Cancel" is selected then return
if isequal([file,path],[0,0])
    set(hObject, 'Visible', 'on');
    set(slider1, 'Visible', 'on');
   	return
end

saveas(gcf,fullfile(path, file));
set(hObject, 'Visible', 'on');
set(slider1, 'Visible', 'on');

function plot_pd(hh,conc,err,stdev_corr)

[pd_conc, pd_val, peak_conc, peak_pos] = probability_density(hh,conc,err./stdev_corr);

[AX,H1,H2] = plotyy(conc,hh,pd_conc,pd_val);
set(H1,'LineStyle','none')
set(H1,'Marker','.')
set(H1,'MarkerSize',8)
set(H1,'Color','k')
set(H2,'Color','r')
set(AX(2),'Visible','Off')
set(AX(1),'XMinorTick' ,'On', 'YMinorTick', 'On')
set(AX(1),'XColor' ,'k', 'YColor', 'k')
set(AX(1),'XLimMode', 'manual','YLimMode', 'manual')
set(AX(2),'XLimMode', 'manual','YLimMode', 'auto')
xlim = [min(pd_conc) max(pd_conc)];
ylim = [(min(hh) - (max(hh) - min(hh))*0.1) (max(hh)+(max(hh) - min(hh))*0.1)];
set(AX(1),'XLim', xlim,'YLim', ylim)
set(AX(2),'XLim', xlim)
xlabel('^{36}Cl concentration normalized to Ca concentration, 10^{5} at g^{-1}')
ylabel('Position along fault scarp, cm')
line('XData',xlim,'YData',[0 0],'Color','b')

for ii = 1:length(peak_conc)
    x = [peak_conc(ii) peak_conc(ii)];
    y = [ylim(1), peak_pos(ii)];
    line('XData',x,'YData',y,'LineStyle', ':')
    x = [peak_conc(ii) xlim(2)];
    y = [peak_pos(ii), peak_pos(ii)];
    line('XData',x,'YData',y,'LineStyle', ':')
    text(x(2) ,y(2), [' ' num2str(round(peak_pos(ii)))])
end

refreshdata


function [pd_conc, pd_val, peak_conc, peak_pos] = probability_density(h_pos,conc,err)

min_conc = min(conc);
max_conc = max(conc);

min_axis = min_conc - (max_conc - min_conc)*0.1;
max_axis = max_conc + (max_conc - min_conc)*0.1;
pd_conc = zeros(1,2000);
pd_val = zeros(1,2000);
for nn = 1:1:2000;
    pd_conc(nn) = min_axis + (max_axis - min_axis)*nn/2000;
    pd_val(nn) = sum(normpdf(pd_conc(nn),conc,err));
end

[useless3, ind] = findpeaks(pd_val);
n_peak = length(ind);
peak_conc = pd_conc(ind);
peak_pos = zeros(1,n_peak);
for ii = 1:n_peak
    [useless4, ind_all] = sort(abs(conc - pd_conc(ind(ii))));
    ind3 = ind_all(1:3);
    peak_pos(ii) = mean(h_pos(ind3));
end