function out = Scarp_Visual_Check(alpha,beta,gamma,s_cov,rho_r,rho_c,rho_s)

% creates a window containing scematic cross-section of fault scarp

% Written by Dmitry Tikhomirov
% Institut fuer Geologie, Universitaet Bern
% tikhomirov@geo.unibe.ch, tikhomirovdmitry@gmail.com
% 2013-2016
%
% This program is free software; you can redistribute it and/or modify it 
% under a Creative Commons Attribution-NonCommercial-ShareAlike 3.0 
% Unported License (http://creativecommons.org/licenses/by-nc-sa/3.0/)

out = figure('Units','characters',...
             'Position', [50, 20, 70, 27],...
             'Name', 'Scarp_Visual_Check',...  
             'NumberTitle', 'off','Color',[0.941, 0.941, 0.941],... 
             'MenuBar', 'none','PaperPositionMode', 'auto');
         
alphar = alpha*pi/180 ;
betar = beta*pi/180 ;
gammar = gamma*pi/180 ;

%scale coefficient
a = 150;

%coordinates of major points
x1 = 0;
y1 = 0;
x2 = a*cos(betar);
y2 = a*sin(betar);
x3 = x2 + a*cos(gammar);
y3 = y2 + a*sin(gammar);
x4 = -2*a*cos(betar);
y4 = -2*a*sin(betar);
x5 = x4 - a;
y5 = (x4 - a)*tan(alphar);

%coordinates of minor points
x6 = -a*cos(betar);
y6 = -a*sin(betar);
x7 = x6 + 0.7*a;
y7 = y6;
x8 = x5 + 0.7*a;
y8 = y5;
x9 = x2+0.7*a;
y9 = y2;
y3p = y3 + 0.5*a;

%sun coordinates
% tc = 0:0.1:2*pi;
% xsun = x5 + 0.4*a + cos(tc)*0.2*a;
% ysun = y3p - 0.4*a + sin(tc)*0.2*a;

%drawing
xsky = [x1 x5 x5 x3 x3 x2];
ysky = [y1 y5 y3p y3p y3 y2];
fill(xsky,ysky,'c');
hold on
axis equal 
axis off


xcoll = [x1 x5 (x4 - a) x4];
ycoll = [y1 y5 y4 y4];
fill(xcoll,ycoll,[1,0.8,0.6]);

xrock = [x4 x2 x3 x3];
yrock = [y4 y2 y3 y4];
fill(xrock,yrock,[0.7,0.7,0.7]);

% fill(xsun,ysun,'y','EdgeColor','y');

if s_cov > 0
    line([x5-0.02*a x1],[y5+0.02*a y1+0.02*a],'Color',[1 1 1],'LineWidth',4);
    line([x2-0.02*a x3],[y2+0.02*a  y3+0.02*a],'Color',[1 1 1],'LineWidth',4);
    line([x5 x1],[y5 y1],'Color',[0 0 0],'LineWidth',0.5);
    line([x2 x3],[y2 y3],'Color',[0 0 0],'LineWidth',0.5);
    text(-1.8*a, 0.9*a, 'Snow cover', 'FontName', 'MS Sans Serif', ...
        'FontSize', 10, 'VerticalAlignment', 'Top');
    text(-1.8*a, 0.6*a, ['depth=' num2str(s_cov) ' cm'], 'FontName', 'MS Sans Serif', ...
        'FontSize', 8, 'VerticalAlignment', 'Top');
    text(-1.8*a, 0.4*a, ['\rho=' num2str(rho_s) ' g cm^{-3}'], 'FontName', 'MS Sans Serif', ...
        'FontSize', 8, 'VerticalAlignment', 'Top');
end


line([x5 x8],[y5 y8],'Color',[0 0 0]);
tc = (-0.1):0.01:(alphar + 0.1);
xalpha = x5 + cos(tc)*0.6*a;
yalpha = y5 + sin(tc)*0.6*a;
plot(xalpha,yalpha,'Color',[0 0 0]);
text(x8, y8, [num2str(alpha) ''], 'FontName', 'MS Sans Serif', ...
        'FontSize', 8, 'VerticalAlignment', 'Top');
    
line([x6 x7],[y6 y7],'Color',[0 0 0]);
tc = (-0.1):0.01:(betar + 0.1);
xalpha = x6 + cos(tc)*0.6*a;
yalpha = y6 + sin(tc)*0.6*a;
plot(xalpha,yalpha,'Color',[0 0 0]);
text(x7, y7, [num2str(beta) ''], 'FontName', 'MS Sans Serif', ...
        'FontSize', 8, 'VerticalAlignment', 'Top');    
        
line([x2 x9],[y2 y9],'Color',[0 0 0]);
tc = (-0.1):0.01:(gammar + 0.1);
xalpha = x2 + cos(tc)*0.6*a;
yalpha = y2 + sin(tc)*0.6*a;
plot(xalpha,yalpha,'Color',[0 0 0]);
text(x9, y9, [num2str(gamma) ''], 'FontName', 'MS Sans Serif', ...
        'FontSize', 8, 'VerticalAlignment', 'Top');    
    
    
text(x5 + 0.07*a, y5 - 0.15*a, 'Colluvium', 'FontName', 'MS Sans Serif', ...
        'FontSize', 10, 'VerticalAlignment', 'Top');   
text(x5 + 0.07*a, y5 - 0.35*a, ['\rho=' num2str(rho_c) ' g cm^{-3}'],  ...
  'FontName', 'MS Sans Serif', 'FontSize', 8, 'VerticalAlignment', 'Top');  
    
    
text(0.4*a, 0.1*a, 'Rock', 'FontName', 'MS Sans Serif', ...
        'FontSize', 10, 'VerticalAlignment', 'Top');   
text(0.4*a, - 0.10*a, ['\rho=' num2str(rho_r) ' g cm^{-3}'],  ...
  'FontName', 'MS Sans Serif', 'FontSize', 8, 'VerticalAlignment', 'Top'); 

text(0.4*a, - 0.45*a, 'Foot wall', 'FontName', 'MS Sans Serif', ...
        'FontSize', 10, 'VerticalAlignment', 'Top'); 
