function out = TpToTopo(azimuth,tp,tp_type)

% converts a topogrphic shielding into matrix "topo" that is used 
% by functions PointShield

% Written by Dmitry Tikhomirov
% Institut fuer Geologie, Universitt Bern
% tikhomirov@geo.unibe.ch, tikhomirovdmitry@gmail.com
% 2013-2016
%
% This program is free software; you can redistribute it and/or modify it 
% under a Creative Commons Attribution-NonCommercial-ShareAlike 3.0 
% Unported License (http://creativecommons.org/licenses/by-nc-sa/3.0/)

if strcmp(tp_type,'bars') == 1
    out = TpBarsTopo(tp,azimuth);
elseif strcmp(tp_type,'points') == 1
    out = TpPointsTopo(tp,azimuth);
else
    error('something wrong with your topographic shielding');
end

end

function Topo = TpBarsTopo(tp,azimuth) 
%This function - TpBarsTopo converts a topogrphic shielding represented in 
%bars into matrix "topo" which is used by functions PointShield. Input
%parameters are:
% azimuth - the azimuth of the fault scarp 
% tp - two columns matrix, which represent a horizon line as bars. 
% The first column is directions, between which horizon line has equal 
% inclination. The second column is inclinations of bars.

topo = ones(360,90);
[nstr,ncol]  = size(tp);
tp = [tp; tp(1,:)];
lencum = 0;
for k = 1:nstr
    
    len = round(tp(k+1,1)) - round(tp(k,1));
    len(len<0) = len + 360;
    topo(lencum+1:lencum + len,1:round(tp(k,2))) = 0;
    lencum = lencum + len;
end
 
Topo = circshift(topo,[360-round(azimuth)+round(tp(1,1)) 0]);
 
end


function Topo = TpPointsTopo(tp,azimuth)
%This function - TpPointsTopo converts a topogrphic shielding represented 
%in broken-line into the matrix "topo" which is used by the functions  
%PointShield. Input parameters are:
% azimuth - the azimuth of the fault scarp
% tp - two columns matrix, which represents a horizon line as broken-line.
% The first column is directions of broken-line vertexes and the second  
% column is inclinations of broken-line vertexes.

topo = ones(360,90);
[nstr,ncol]  = size(tp);
tp = [tp; tp(1,:)];
lencum = 0;

for k = 1:nstr
    
    len = round(tp(k+1,1)) - round(tp(k,1));
    len(len<0) = len + 360;
    b = (tp(k+1,2) - tp(k,2))/len;
    a = tp(k,2) - b*tp(k,1);
    
    for j = (lencum+1):(lencum + len)
        incl = round((tp(1,1) + j - 0.5)*b + a);
        topo(j,1:incl) = 0;
    end
    lencum = lencum + len;
end

Topo = circshift(topo,[360-round(azimuth)+tp(1,1)- 1 0]);

end
